10. cdist-dump(1) — cdist 6.9.4 documentation

# 10. cdist-dump(1)

## 10.1. NAME

cdist-dump - Dump data from local cdist cache

## 10.2. SYNOPSIS

    cdist-dump [options] [host...]

## 10.3. DESCRIPTION

cdist-dump is a helper script that dumps data from local cdist cache for specified hosts. If host is not specified then all data from cache directory is dumped. Default cache directory is '~/.cdist/cache'.

cdist-dump can be used for debugging existing types, host configuration and new types.

## 10.4. OPTIONS

-a

  dump all

-C CACHE-DIR

  use specified CACHE-DIR (default: ~/.cdist/cache)

-c

  dump code-*

-d DELIMITER

  delimiter used for filename and line number prefix (default: ':')

-E

  dump global explorers

-e

  dump type explorers

-F

  disable filename prefix (enabled by default)

-f

  enable filename prefix (default)

-g

  dump gencode-*

-h

  show this help screen and exit

-L

  disable line number prefix (default)

-l

  enable line number prefix (disabled by default)

-m

  dump messages

-o

  dump executions' stdout

-p

  dump parameters

-r

  dump executions' stderr

-V

  show version and exit

-v

  increase verbosity

## 10.5. EXAMPLES

    # Dump all
    % cdist-dump -a

    # Dump only code-* output
    % cdist-dump -c

## 10.6. SEE ALSO

cdist(1)

## 10.7. AUTHORS

Darko Poljak <darko.poljak--@--ungleich.ch>

## 10.8. COPYING

Copyright (C) 2019 Darko Poljak. Free use of this software is granted under the terms of the GNU General Public License v3 or later (GPLv3+).